@@ -86,9 +86,6 @@ SPECIAL_CASES = {"the shit": 3, "the bomb": 3, "bad ass": 1.5, "badass": 1.5, "b
 
 
 
-# Mot à ne pas nier
-with open("vaderSentiment_fr/no_negate.txt",'r') as f :
-    NO_NEGATE = f.read().strip().split("\n")
 
 
 # #Static methods# #
@@ -113,21 +110,21 @@ def negated(input_words, include_nt=True):
             return True'''
     return False
 
-
 def normalize(score, alpha=15):
     """
     Normalize the score to be between -1 and 1 using an alpha that
     approximates the max expected value
     """
-    norm_score = -5*score / math.sqrt((score * score) + alpha) + 5
-    if norm_score < 0.0:
-        return -0.0
-    elif norm_score > 10.0:
-        return 10.0
+    norm_score = score / math.sqrt((score * score) + alpha)
+    if norm_score < -1.0:
+        return -1.0
+    elif norm_score > 1.0:
+        return 1.0
     else:
         return norm_score
 
 
+
 def allcap_differential(words):
     """
     Check whether just some words in the input are ALL CAPS
@@ -232,6 +229,13 @@ class SentimentIntensityAnalyzer(object):
         self.emojis = self.make_emoji_dict()
         self.treenode = self.make_tree()
 
+        # Mots à ne pas nier
+        no_negate_full_filepath = os.path.join(
+            os.path.dirname(_this_module_file_path_), "no_negate.txt")
+
+        with codecs.open(no_negate_full_filepath,'r') as f :
+            NO_NEGATE = f.read().strip().split("\n")
+
 
     def make_tree(self):
         words = list(self.lexicon.keys())
@@ -328,10 +332,6 @@ class SentimentIntensityAnalyzer(object):
 
         valence_dict = self.score_valence(sentiments, text)
         # Création du dictionnaire pour obtenir à chaque mot la valeur attribuée
-        details = {}
-        for i in range(len(sentiments)):
-            details[words_and_emoticons[i]]=sentiments[i]
-        valence_dict["details"] = details
 
         return valence_dict
 
